<p align="center">
<img src="http://www.kima.science/assets/img/logo.png" 
     width="200" alt="Logo created by Solène Ulmer-Moll">

<p align="center">
     A data analysis framework for exoplanet detection
</p>
</p>
